# Installation

Run `composer require dedi/sylius-maintenance-plugin`

Add plugin class to your `config/bundles.php`:

```php
<?php
$bundles = [
    // ...
    Dedi\SyliusMaintenancePlugin\DediSyliusMaintenancePlugin::class => ['all' => true],
    // ...
];
```

# Basic Configuration

## Import the plugin configuration

```yaml
# config/packages/dedi_sylius_maintenance.yaml

imports:
    - { resource: "@DediSyliusMaintenancePlugin/config/config.yaml" }

```

## Import routing

```yaml
# config/routes.yaml

dedi_sylius_maintenance_shop:
    resource: "@DediSyliusMaintenancePlugin/config/shop_routing.yml"
    prefix: /{_locale}
    requirements:
        _locale: ^[a-z]{2}(?:_[A-Z]{2})?$
```

## Extend your `Channel` Entity and Interface

```php
<?php

namespace App\Entity;

use Dedi\SyliusMaintenancePlugin\Model\ChannelInterface as MaintenanceChannelInterface;
use Sylius\Component\Core\Model\ChannelInterface as BaseChannelInterface;

interface ChannelInterface extends BaseChannelInterface, MaintenanceChannelInterface
{
}
```

```php
<?php

namespace App\Entity;

use Dedi\SyliusMaintenancePlugin\Model\ChannelTrait;
use Sylius\Component\Core\Model\Channel as BaseChannel;

class Channel extends BaseChannel
{
    use ChannelTrait;
}
```

## Add configuration

```yaml
# config/packages/_sylius.yaml

sylius_channel:
    resources:
        channel:
            classes:
                model: App\Entity\Channel
                interface: App\Entity\ChannelInterface
```

## Create migration

Create migration with `bin/console doctrine:migration:diff`

The migration should look like this

```php
    public function getDescription(): string
    {
        return '';
    }

    public function up(Schema $schema): void
    {
        $this->addSql('ALTER TABLE sylius_channel ADD maintenance_activated TINYINT(1) DEFAULT \'0\' NOT NULL, ADD maintenance_ip_list VARCHAR(255) DEFAULT NULL');
    }

    public function down(Schema $schema): void
    {
        $this->addSql('ALTER TABLE sylius_channel DROP maintenance_activated, DROP maintenance_ip_list');
    }
```
